@@ -19,6 +19,7 @@ pub struct EntryData {
     /// The entry's size in bytes. If it's a directory, the size is the aggregated file size of all children
     pub size: u128,
     pub mtime: SystemTime,
+    pub entry_count: Option<u64>,
     /// If set, the item meta-data could not be obtained
     pub metadata_io_error: bool,
 }
@@ -29,6 +30,7 @@ impl Default for EntryData {
             name: PathBuf::default(),
             size: u128::default(),
             mtime: UNIX_EPOCH,
+            entry_count: None,
             metadata_io_error: bool::default(),
         }
     }
@@ -39,6 +41,7 @@ impl fmt::Debug for EntryData {
         f.debug_struct("EntryData")
             .field("name", &self.name)
             .field("size", &self.size)
+            .field("entry_count", &self.entry_count)
             // Skip mtime
             .field("metadata_io_error", &self.metadata_io_error)
             .finish()
@@ -70,17 +73,41 @@ impl Traversal {
         input: Vec<PathBuf>,
         mut update: impl FnMut(&mut Traversal) -> Result<bool>,
     ) -> Result<Option<Traversal>> {
-        fn set_size_or_panic(tree: &mut Tree, node_idx: TreeIndex, current_size_at_depth: u128) {
-            tree.node_weight_mut(node_idx)
-                .expect("node for parent index we just retrieved")
-                .size = current_size_at_depth;
+        #[derive(Default, Copy, Clone)]
+        struct EntryInfo {
+            size: u128,
+            entries_count: Option<u64>,
+        }
+        impl EntryInfo {
+            fn add_count(&mut self, other: &Self) {
+                self.entries_count = match (self.entries_count, other.entries_count) {
+                    (Some(a), Some(b)) => Some(a + b),
+                    (None, Some(b)) => Some(b),
+                    (Some(a), None) => Some(a),
+                    (None, None) => None,
+                };
+            }
+        }
+        fn set_entry_info_or_panic(
+            tree: &mut Tree,
+            node_idx: TreeIndex,
+            EntryInfo {
+                size,
+                entries_count,
+            }: EntryInfo,
+        ) {
+            let node = tree
+                .node_weight_mut(node_idx)
+                .expect("node for parent index we just retrieved");
+            node.size = size;
+            node.entry_count = entries_count;
         }
         fn parent_or_panic(tree: &mut Tree, parent_node_idx: TreeIndex) -> TreeIndex {
             tree.neighbors_directed(parent_node_idx, Direction::Incoming)
                 .next()
                 .expect("every node in the iteration has a parent")
         }
-        fn pop_or_panic(v: &mut Vec<u128>) -> u128 {
+        fn pop_or_panic(v: &mut Vec<EntryInfo>) -> EntryInfo {
             v.pop().expect("sizes per level to be in sync with graph")
         }
 
@@ -99,8 +126,8 @@ impl Traversal {
         };
 
         let (mut previous_node_idx, mut parent_node_idx) = (t.root_index, t.root_index);
-        let mut sizes_per_depth_level = Vec::new();
-        let mut current_size_at_depth: u128 = 0;
+        let mut directory_info_per_depth_level = Vec::new();
+        let mut current_directory_at_depth = EntryInfo::default();
         let mut previous_depth = 0;
         let mut inodes = InodeFilter::default();
 
@@ -162,6 +189,8 @@ impl Traversal {
                                             })
                                             as u128;
                                     }
+                                } else {
+                                    data.entry_count = Some(0);
                                 }
 
                                 match m.modified() {
@@ -183,30 +212,39 @@ impl Traversal {
 
                         match (entry.depth, previous_depth) {
                             (n, p) if n > p => {
-                                sizes_per_depth_level.push(current_size_at_depth);
-                                current_size_at_depth = file_size;
+                                directory_info_per_depth_level.push(current_directory_at_depth);
+                                current_directory_at_depth = EntryInfo {
+                                    size: file_size,
+                                    entries_count: Some(1),
+                                };
                                 parent_node_idx = previous_node_idx;
                             }
                             (n, p) if n < p => {
                                 for _ in n..p {
-                                    set_size_or_panic(
+                                    set_entry_info_or_panic(
                                         &mut t.tree,
                                         parent_node_idx,
-                                        current_size_at_depth,
+                                        current_directory_at_depth,
                                     );
-                                    current_size_at_depth +=
-                                        pop_or_panic(&mut sizes_per_depth_level);
+                                    let dir_info =
+                                        pop_or_panic(&mut directory_info_per_depth_level);
+
+                                    current_directory_at_depth.size += dir_info.size;
+                                    current_directory_at_depth.add_count(&dir_info);
+
                                     parent_node_idx = parent_or_panic(&mut t.tree, parent_node_idx);
                                 }
-                                current_size_at_depth += file_size;
-                                set_size_or_panic(
+                                current_directory_at_depth.size += file_size;
+                                *current_directory_at_depth.entries_count.get_or_insert(0) += 1;
+                                set_entry_info_or_panic(
                                     &mut t.tree,
                                     parent_node_idx,
-                                    current_size_at_depth,
+                                    current_directory_at_depth,
                                 );
                             }
                             _ => {
-                                current_size_at_depth += file_size;
+                                current_directory_at_depth.size += file_size;
+                                *current_directory_at_depth.entries_count.get_or_insert(0) += 1;
                             }
                         };
 
@@ -235,15 +273,25 @@ impl Traversal {
             }
         }
 
-        sizes_per_depth_level.push(current_size_at_depth);
-        current_size_at_depth = 0;
+        directory_info_per_depth_level.push(current_directory_at_depth);
+        current_directory_at_depth = EntryInfo::default();
         for _ in 0..previous_depth {
-            current_size_at_depth += pop_or_panic(&mut sizes_per_depth_level);
-            set_size_or_panic(&mut t.tree, parent_node_idx, current_size_at_depth);
+            let dir_info = pop_or_panic(&mut directory_info_per_depth_level);
+            current_directory_at_depth.size += dir_info.size;
+            current_directory_at_depth.add_count(&dir_info);
+
+            set_entry_info_or_panic(&mut t.tree, parent_node_idx, current_directory_at_depth);
             parent_node_idx = parent_or_panic(&mut t.tree, parent_node_idx);
         }
         let root_size = t.recompute_root_size();
-        set_size_or_panic(&mut t.tree, t.root_index, root_size);
+        set_entry_info_or_panic(
+            &mut t.tree,
+            t.root_index,
+            EntryInfo {
+                size: root_size,
+                entries_count: (t.entries_traversed > 0).then_some(t.entries_traversed),
+            },
+        );
         t.total_bytes = Some(root_size);
 
         t.elapsed = Some(t.start.elapsed());
@@ -266,7 +314,7 @@ mod tests {
     fn size_of_entry_data() {
         assert_eq!(
             std::mem::size_of::<EntryData>(),
-            64,
+            80,
             "the size of this should not change unexpectedly as it affects overall memory consumption"
         );
     }
